==================================================
djmongo - A Drop-in Django Application for MongoDB
==================================================

django-djmongo is an "API in a Box".  It provides a web-based UI for MongoDB,
the ability to import data, and create RESTful APIs without the need to 
write code. For beginers, you may find it helpfult to start a sample project
with Djmongo already configured. https://github.com/videntity/djmsample 


See https://github.com/videntity/django-djmongo/wiki/Installation for 
installation instructions.
